@@ -9,6 +9,7 @@ from typing import List, Tuple, Optional, BinaryIO
 
 import requests
 from google.cloud import storage, pubsub
+from werkzeug.datastructures import FileStorage
 
 from ..config.settings import (
     GOOGLE_DOWNLOAD_ROLE,
@@ -31,11 +32,15 @@ from ..config.logging import get_logger
 
 logger = get_logger(__name__)
 
+storage_client = None
+
 
 def _get_bucket(bucket_name: str) -> storage.Bucket:
     """Get the bucket with name `bucket_name` from GCS."""
-    client = storage.Client()
-    bucket = client.get_bucket(bucket_name)
+    global storage_client
+    if storage_client is None:
+        storage_client = storage.Client()
+    bucket = storage_client.get_bucket(bucket_name)
     return bucket
 
 
@@ -92,6 +97,27 @@ def upload_xlsx_to_gcs(
     return final_object
 
 
+def upload_xlsx_to_intake_bucket(
+    user, trial_id: str, assay_type: str, xlsx: FileStorage
+) -> str:
+    """
+    Upload a metadata spreadsheet file to the GCS intake bucket, 
+    returning the URL to the bucket in the GCP console.
+    """
+    # get the intake bucket subdirectory for this upload
+    blob_prefix = _build_intake_prefix(user.id, user.email, trial_id, assay_type)
+    # add a timestamp to the metadata file name to avoid overwriting previous versions
+    filename_with_timestamp = f'{xlsx.filename.rsplit(".xlsx", 1)[0]}_{datetime.datetime.now().isoformat()}.xlsx'
+    blob_name = f"{blob_prefix}/{filename_with_timestamp}"
+
+    # upload the metadata spreadsheet to the intake bucket
+    bucket = _get_bucket(GOOGLE_INTAKE_BUCKET)
+    blob = bucket.blob(blob_name)
+    blob.upload_from_file(xlsx)
+
+    return f"https://console.cloud.google.com/storage/browser/_details/{GOOGLE_INTAKE_BUCKET}/{blob_name}"
+
+
 def grant_upload_access(user_email: str):
     """
     Grant a user upload access to the GOOGLE_UPLOAD_BUCKET. Upload access
